@@ -16,7 +16,9 @@
 """
 from nonebot.matcher import Matcher
 from nonebot.typing import T_State
-from typing import Tuple
+from nonebot.params import CommandArg,ArgPlainText,RegexGroup,Arg,Command,RawCommand
+
+from typing import Tuple,Union,List
 from time import sleep
 from .config import *
 from .utils import *
@@ -28,16 +30,18 @@ from nonebot import get_driver
 from .l4d2_image.vtfs import img_to_vtf
 from .l4d2_queries.ohter import load_josn
 from .l4d2_queries.qqgroup import write_json,ip_anne_list
-from .l4d2_file import updown_l4d2_vpk
+from .l4d2_file import updown_l4d2_vpk,all_zip_to_one
+from .l4d2_queries.maps import seach_map,map_dict_to_str
 from .txt_to_img import mode_txt_to_img
 # from .l4d2_server import RCONClient
 from nonebot import get_bot, require
+# from .l4d2_server import web,webUI
 scheduler = require("nonebot_plugin_apscheduler").scheduler
 
 driver = get_driver()
 
 
-__version__ = "0.3.3"
+__version__ = "0.3.6"
 __plugin_meta__ = PluginMetadata(
     name="求生之路小助手",
     description='群内对有关求生之路的查询和操作',
@@ -141,7 +145,6 @@ async def _(bot:Bot,event: MessageEvent):
     msg = mes_list(msg,name_vpk).replace(" ","")
     
     await find_vpk.finish(mode_txt_to_img(mes,msg))
-    # await find_vpk.finish(msg)
 
 @del_vpk.handle()
 async def _(matcher:Matcher,args:Message = CommandArg()):
@@ -289,6 +292,8 @@ async def _(event:GroupMessageEvent,matcher:Matcher,args:Message = CommandArg())
 async def _(event:GroupMessageEvent):
     group_id = event.group_id
     msg = await show_ip(group_id)
+    if not msg:
+        await show_queries.finish("当前没有启动的服务器捏")
     if type(msg) == str:
         await show_queries.finish(msg)
     else:
@@ -312,25 +317,46 @@ async def _(state:T_State,tag:str = ArgPlainText("ip")):
     msg = await workshop_msg(tag)
     if not msg:
         await up_workshop.finish('没有这个物品捏')
-    pic = await url_to_byte(msg['图片地址'])
-    message = ''
-    for item,value in msg.items():
-        if item in ['图片地址','下载地址']:
-            continue
-        message += item + ':' + value + '\n'
-    state['dic'] = msg
-    await up_workshop.send(MessageSegment.image(pic) + Message(message))
+    elif type(msg) == dict:
+        pic = await url_to_byte(msg['图片地址'])
+        message = ''
+        for item,value in msg.items():
+            if item in ['图片地址','下载地址','细节']:
+                continue
+            message += item + ':' + value + '\n'
+        state['dic'] = msg
+        await up_workshop.send(MessageSegment.image(pic) + Message(message))
+    elif type(msg) == list:
+        lenge = len(msg)
+        pic = await url_to_byte(msg[0]['图片地址'])
+        message = f'有{lenge}个文件\n'
+        for one in msg:
+            ones = []
+            for item,value in one.items():
+                if item in ['图片地址','下载地址','细节']:
+                    continue
+                message += item + ':' + value + '\n'
+            ones.append(one)
+        state['dic'] = ones
     
 @up_workshop.got("is_sure",prompt='如果需要上传，请发送 "yes"')    
 async def _(matcher: Matcher,bot:Bot,event:GroupMessageEvent,state:T_State):
     is_sure = str(state["is_sure"])
     if is_sure == 'yes':
-        data_dict:dict = state['dic']
-        logger.info('开始上传')
-        data_file = await url_to_byte(data_dict['下载地址'])
-        file_name = data_dict['名字']+ '.vpk'
-        await up_workshop.send('获取地址成功，尝试上传')
-        await upload_file(bot, event, data_file, file_name)
+        data_dict:Union[dict,List[dict]] = state['dic']
+        if type(data_dict) == dict:
+            logger.info('开始上传')
+            data_file = await url_to_byte(data_dict['下载地址'])
+            file_name = data_dict['名字']+ '.vpk'
+            await up_workshop.send('获取地址成功，尝试上传')
+            await upload_file(bot, event, data_file, file_name)
+        else:
+            logger.info('开始上传')
+            for data_one in data_dict:
+                data_file = await url_to_byte(data_one['下载地址'])
+                await all_zip_to_one
+            file_name = data_one['名字']+ '.vpk'
+            await upload_file(bot, event, data_file, file_name)
     else:
         await up_workshop.finish('已取消上传')
     
@@ -351,21 +377,14 @@ async def _(args:Message = CommandArg()):
 @read_ip.handle()
 async def _():
     img = await qq_ip_queries_pic(ip_anne_list)
+    if img == None:
+        return "电信服的地址请加主群自行填写哦"
     await read_ip.finish(MessageSegment.image(img))
 
 @tan_jian.handle()
 async def _(event:MessageEvent):
-    group = event.user_id
     await tan_jian.send('正在寻找牢房...')
-    ip_list = []
-    keys = ANNE_IP.keys()
-    for key in keys:
-        key:str
-        if key.startswith('云'):
-            ip = ANNE_IP[key]
-            host,port = split_maohao(ip)
-            ip_list.append((key,group,host,port))
-    msg = await get_tan_jian(ip_list,1)
+    msg = await get_tan_jian(ip_anne_list,1)
     await tan_jian.finish(msg)
 
 @get_ip.handle()
@@ -380,7 +399,10 @@ async def _(command: str = RawCommand(),args:Message = CommandArg()):
             host,port = split_maohao(one_ip['ip'])
             ip_list.append((one_ip['id'],host,port))
         img = await qq_ip_queries_pic(ip_list)
-        await read_ip.finish(MessageSegment.image(img))
+        if img:
+            await read_ip.finish(MessageSegment.image(img)) 
+        else:
+            await read_ip.finish("服务器无响应")
     else:
         message = await json_server_to_tag_dict(command,msg)
         if len(message) == 0:
@@ -422,34 +444,39 @@ async def _(bot:Bot,event:MessageEvent,state:T_State,tag = Arg("image")):
 
 @prison.handle()
 async def _(event:MessageEvent):
-    group = event.user_id
-    await tan_jian.send('正在寻找缺人...')
-    ip_list = []
-    keys = ANNE_IP.keys()
-    for key in keys:
-        key:str
-        if key.startswith('云'):
-            ip = ANNE_IP[key]
-            host,port = split_maohao(ip)
-            ip_list.append((key,group,host,port))
-    msg = await get_tan_jian(ip_list,2)
+    msg = await get_tan_jian(ip_anne_list,2)
     await tan_jian.finish(msg)
 
 @open_prison.handle()
 async def _(event:MessageEvent):
-    group = event.user_id
-    await tan_jian.send('正在寻找空房...')
-    ip_list = []
-    keys = ANNE_IP.keys()
-    for key in keys:
-        key:str
-        if key.startswith('云'):
-            ip = ANNE_IP[key]
-            host,port = split_maohao(ip)
-            ip_list.append((key,group,host,port))
-    msg = await get_tan_jian(ip_list,3)
+
+    msg = await get_tan_jian(ip_anne_list,3)
     await tan_jian.finish(msg)
 
+@smx_file.handle()
+async def _():
+    smx_path = Path(l4_file[CHECK_FILE],"left4dead2/addons/sourcemod/plugins")
+    smx_list = []
+    name_smx = get_vpk(smx_list,smx_path,file_=".smx")
+    logger.info("获取文件列表成功")
+    mes = "当前服务器下有以下smx文件"
+    msg = ''
+    msg = mes_list(msg,name_smx).replace(" ","")
+    await find_vpk.finish(mode_txt_to_img(mes,msg))
+    
+@search_api.handle()
+async def _(args:Message = CommandArg()):
+    msg:str = args.extract_plain_text()
+    # if msg.startswith('代码'):
+        # 建图代码返回三方图信息
+    data = await seach_map(msg,l4_master[0],l4_key)
+    # else:
+    if type(data) == str:
+        await search_api.finish(data)
+    else:
+        await search_api.finish(await map_dict_to_str(data))
+        
+    
 @driver.on_shutdown
 async def close_db():
     """关闭数据库"""
