@@ -54,19 +54,26 @@ async def qq_ip_queries(msg:List[tuple]):
 async def qq_ip_queries_pic(msg:list):
     """输入一个ip的三元元组组成的列表，返回一个输出消息的图片"""
     msg_list = []
+    pic = None
     if msg != []:
         for i in msg:
-            number,host,port = i
             try:
-                msg2 = await player_queries_anne_dict(host,port)
-                msg1 = await queries_dict(host,port)
-                msg1.update({'Players':msg2})
-                msg1.update({'number':number})
-                # msg1是一行数据完整的字典
-                msg_list.append(msg1)
-            except errors:
-                pass
+                number,host,port = i
+            except ValueError:
+                number,qqgroup,host,port = i
+            finally:
+                try:
+                    msg2 = await player_queries_anne_dict(host,port)
+                    msg1 = await queries_dict(host,port)
+                    msg1.update({'Players':msg2})
+                    msg1.update({'number':number})
+                    # msg1是一行数据完整的字典
+                    msg_list.append(msg1)
+                except errors:
+                    continue
         pic = await server_ip_pic(msg_list)
+    if pic == None:
+        return None
     return pic
     
 async def get_tan_jian(msg:List[tuple],mode:int):
@@ -243,10 +250,12 @@ async def write_json(data_str:str):
                         return '删除成功喵'
                 return '序号不正确，请输入【求生更新 删除 腐竹 序号】'
         return '腐竹名不存在，请输入【求生更新 删除 腐竹 序号】'    
-    
-
-ips = ALL_HOST['云']
-ip_anne_list = []
-for one_ip in ips:
-    host,port = split_maohao(one_ip['ip'])
-    ip_anne_list.append((one_ip['id'],host,port))
\ No newline at end of file
+ip_anne_list=[] 
+try:
+    ips = ALL_HOST['云']
+    ip_anne_list = []
+    for one_ip in ips:
+        host,port = split_maohao(one_ip['ip'])
+        ip_anne_list.append((one_ip['id'],host,port))
+except KeyError:
+    pass
\ No newline at end of file
