@@ -6,7 +6,7 @@ import httpx
 import os
 from pathlib import Path
 
-from typing import List,Dict
+from typing import List,Dict,Union
 from .txt_to_img import txt_to_img
 from .config import *
 from .l4d2_anne import write_player,del_player,anne_messgae
@@ -14,11 +14,10 @@ from .l4d2_server.rcon import read_server_cfg_rcon,rcon_server
 from .l4d2_queries import queries,player_queries
 from .l4d2_queries.qqgroup import *
 from .l4d2_server.workshop import workshop_to_dict
-from .l4d2_queries.ohter import ANNE_HOST
+from .l4d2_queries.ohter import ALL_HOST
 from .l4d2_image.steam import url_to_byte
 import tempfile
 import random
-import a2s
 
 async def get_file(url:str,down_file:Path):
     '''
@@ -43,12 +42,12 @@ async def get_file(url:str,down_file:Path):
         mes = None
     return mes
 
-def get_vpk(vpk_list:list,path):
+def get_vpk(vpk_list:list,path,file_:str = '.vpk'):
     '''
     获取所有vpk文件
     '''
     for file in os.listdir(path):
-        if file.endswith('.vpk'):
+        if file.endswith(file_):
             vpk_list.append(file)
     return vpk_list
 
@@ -102,10 +101,7 @@ def solve(msg:str):
 
 async def search_anne(name:str,usr_id:str):
     """获取anne成绩"""
-    msg = await anne_messgae(name,usr_id)
-    if type(msg) == str:
-        msg = solve(msg)
-    return msg
+    return await anne_messgae(name,usr_id)
     
 
 async def bind_steam(id:str,msg:str,nickname:str):
@@ -169,7 +165,7 @@ async def queries_server(msg:list) -> str:
     try:
         msgs = await  queries(ip,port)
         msgs += await player_queries(ip,port)
-    except (KeyError,struct.error,TimeoutError):
+    except (struct.error,TimeoutError):
         pass
     # except Exception:
         # msgs = '有无法识别的用户名'
@@ -191,8 +187,6 @@ async def show_ip(group_id):
     if len(data_list) == 0 :
         return "本群没有订阅"
     msg = await qq_ip_queries_pic(data_list)
-    if type(msg) == str:
-        msg = solve(msg)
     return  msg
 
 async def get_number_url(number):
@@ -212,7 +206,7 @@ async def workshop_msg(msg:str):
             pass
         msg = msg.replace('https://steamcommunity.com/sharedfiles/filedetails/?id=','')
     if msg.isdigit():
-        data:Dict = await workshop_to_dict(msg)
+        data:Union[dict,List[dict]] = await workshop_to_dict(msg)
         return data
     else:
         return None
@@ -223,7 +217,7 @@ async def save_file(file:bytes,path_name):
         files.write(file)
         
 async def get_anne_server_ip(ip):
-    """输出查询ip"""
+    """输出查询ip和ping"""
     host,port = split_maohao(ip)
     data = await queries_server([host,port])
     lines = data.splitlines()
@@ -256,7 +250,7 @@ async def json_server_to_tag_dict(key:str,msg:str):
     msg = msg.replace(' ','')
     n = 0
     # 腐竹循环
-    for tag,value in ANNE_HOST.items():
+    for tag,value in ALL_HOST.items():
         value:List[dict]  
         if tag == key:
             data_dict.update({'server':tag})
@@ -264,13 +258,13 @@ async def json_server_to_tag_dict(key:str,msg:str):
             if msg == '':
                 # 腐竹
                 data_dict.update(random.choice(value))
-            # 腐竹 + 序号
             elif msg.isdigit():
+                logger.info("腐竹 + 序号")
                 for server in value:
                     if msg == str(server['id']):
                         data_dict.update(server)
             else:
-                # 腐竹 + 模式 + 序号
+                logger.info("腐竹 + 模式 + 序号")
                 for server in value:
                     if msg.startswith(server['version']):
                         n = 2
